local modUtil = require "merk_modutil_1_1"
require "stringutil"

local options_zacns = {
	zacns_fake_model = { type = "boolean", default = false, name = _("Fake Version"), description = _("option_zans_1_desc"), image = "res/textures/ui/models_small/vehicle/waggon/zacns_95_gatx_fake.tga" },	
}

local files = {
	"zacns_95_gatx.mdl",
	"zacns_95_green_cargo.mdl",
	"zans_95_ermewa.mdl",	
	"zans_95_ermewa_omv.mdl",
	"zans_95_gatx.mdl",
	"zans_95_gatx_dhl.mdl",
	"zans_95_kvg.mdl",
	"zans_95_onrail.mdl",
	"zans_95_schwechat.mdl",
	"zans_95_vtg.mdl",
	"zans_95_wascosa.mdl",
	"zans_95_wascosa_omv.mdl",	
}

local function isValidFile(fileName)
	for i = 1, #files do
		if string.ends (fileName, files[i]) then
			return true
		end
	end
	
	return false
end

local function vehicleHandler(fileName, data)
	--[[ Hilfsfunktion(en) Anfang]]

	local function findOnGameCargoTypes ( entry )
		for i = 1, #game.config.cargotypes do
			if entry == game.config.cargotypes[i].id then
				return true
			end
		end
		
		return false
	end
	
	local function doIt ( capacities )
		local result = { }
		for i = 1, #capacities do
			if findOnGameCargoTypes (capacities[i].type) then
				result[#result + 1] = capacities[i]
			end
		end
		
		-- Sind keine Güterarten mehr gültig, so setzen wir 6 beliebige, vorhandene Güterarten ein.
		if #result == 0 then
			for i = 1, #game.config.cargotypes do
				if game.config.cargotypes[i].id ~= "PASSENGERS" then
					result[#result + 1] = {
						type = game.config.cargotypes[i].id,
						capacity = 32,
					}
					if #result == 6 then
						break
					end
				end
			end
		end
		return result
	end
		--[[ Hilfsfunktion(en) Ende]]
		
	if isValidFile (fileName) and data.metadata and data.metadata.transportVehicle and data.metadata.transportVehicle.capacities then
		data.metadata.transportVehicle.capacities = doIt (data.metadata.transportVehicle.capacities)
	end
	return data
end

function data()
return {
	info = {
		minorVersion = 7,
		severityAdd = "NONE",
		severityRemove = "WARNING",
		name = _("info_zacns_name"),
		description = _("info_zacns_desc"),
		tags = { "Europe", "Wagon", },
		authors = {
			{
				name = "Kaleut1988",
				role = "CREATOR",
				tfnetId = 22532,
			},
			{
				name = "Nando",
				role = "CO_CREATOR",
				tfnetId = 22322,
			},
			{
				name = "EAT1963",
				role = "CO_CREATOR",
				text = "cargo script",
				tfnetId = 19725,				
			},
			{
				name = "baubus",
				role = "CO_CREATOR",
				text = "soundset",
				tfnetId = 18332,				
			},			
		},
		tfnetId = 2682,                 															-- optional, transportfever.net id
		steamId = 852829904,             															-- optional, steam workshop id
		url = "https://www.transportfever.net/filebase/index.php/Entry/2682-Kesselwagen-Zans-Zacns-95m3/", 	-- optional, URL zur Webseite des Mods
		visible = true,		
	},
	settings = options_zacns,
		
	runFn = function(settings)
		modUtil.initialize("kaleut_zacns", options_zacns, files)
		addModifier( "loadModel", vehicleHandler )
		local settings = modUtil.userSettings.get("kaleut_zacns")	
		if not settings.zacns_fake_model then
			modUtil.vehicles.hideObject("vehicle/waggon/zacns_95_gatx_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zacns_95_green_cargo_fake.mdl")	
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_ermewa_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_ermewa_omv_fake.mdl")	
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_gatx_dhl_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_gatx_fake.mdl")	
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_kvg_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_onrail_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_schwechat_fake.mdl")	
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_vtg_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_wascosa_fake.mdl")
			modUtil.vehicles.hideObject("vehicle/waggon/zans_95_wascosa_omv_fake.mdl")			
		end		
		
	end
}
end
